| /freebsd-13.1/sys/sys/ |
| H A D | smr_types.h | 57 type __ptr; /* Do not access directly */ \ 65 (__typeof((p)->__ptr))atomic_load_acq_ptr((uintptr_t *)&(p)->__ptr); \ 75 (__typeof((p)->__ptr))atomic_load_ptr(&(p)->__ptr); \ 88 __typeof((p)->__ptr) _v = (v); \ 101 __typeof((p)->__ptr) _v = (v); \ 104 (__typeof((p)->__ptr))atomic_swap_ptr( \ 105 (uintptr_t *)&(p)->__ptr, (uintptr_t)_v); \ 115 (__typeof((p)->__ptr))atomic_load_ptr(&(p)->__ptr); \ 125 __typeof((p)->__ptr) _v = (v); \ 126 atomic_store_ptr((uintptr_t *)&(p)->__ptr, (uintptr_t)_v); \ [all …]
|
| H A D | sysctl.h | 412 bool *__ptr = (ptr); \ 432 int8_t *__ptr = (ptr); \ 452 uint8_t *__ptr = (ptr); \ 472 int16_t *__ptr = (ptr); \ 492 uint16_t *__ptr = (ptr); \ 512 int32_t *__ptr = (ptr); \ 532 uint32_t *__ptr = (ptr); \ 552 int64_t *__ptr = (ptr); \ 572 uint64_t *__ptr = (ptr); \ 595 int *__ptr = (ptr); \ [all …]
|
| /freebsd-13.1/contrib/llvm-project/libcxx/src/ |
| H A D | atomic.cpp | 38 static void __libcpp_platform_wait_on_address(__cxx_atomic_contention_t const volatile* __ptr, in __libcpp_platform_wait_on_address() argument 42 syscall(SYS_futex, __ptr, FUTEX_WAIT_PRIVATE, __val, &__timeout, 0, 0); in __libcpp_platform_wait_on_address() 45 static void __libcpp_platform_wake_by_address(__cxx_atomic_contention_t const volatile* __ptr, in __libcpp_platform_wake_by_address() argument 48 syscall(SYS_futex, __ptr, FUTEX_WAKE_PRIVATE, __notify_one ? 1 : INT_MAX, 0, 0, 0); in __libcpp_platform_wake_by_address() 60 static void __libcpp_platform_wait_on_address(__cxx_atomic_contention_t const volatile* __ptr, 64 const_cast<__cxx_atomic_contention_t*>(__ptr), __val, 0); 67 static void __libcpp_platform_wake_by_address(__cxx_atomic_contention_t const volatile* __ptr, 71 const_cast<__cxx_atomic_contention_t*>(__ptr), 0); 78 static void __libcpp_platform_wait_on_address(__cxx_atomic_contention_t const volatile* __ptr, 82 … return !__cxx_nonatomic_compare_equal(__cxx_atomic_load(__ptr, memory_order_relaxed), __val);
|
| /freebsd-13.1/contrib/llvm-project/libcxx/include/__algorithm/ |
| H A D | push_heap.h | 36 _RandomAccessIterator __ptr = __first + __len; in __sift_up() local 37 if (__comp(*__ptr, *--__last)) in __sift_up() 42 *__last = _VSTD::move(*__ptr); in __sift_up() 43 __last = __ptr; in __sift_up() 47 __ptr = __first + __len; in __sift_up() 48 } while (__comp(*__ptr, __t)); in __sift_up()
|
| /freebsd-13.1/contrib/ofed/libibverbs/ |
| H A D | config.h | 6 void *__ptr; \ 7 if (posix_memalign(&__ptr, (align), (size))) \ 8 __ptr = NULL; \ 9 __ptr; \
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/Headers/ |
| H A D | __clang_hip_runtime_wrapper.h | 79 __device__ void *__hip_free(void *__ptr); 83 __attribute__((weak)) inline __device__ void *free(void *__ptr) { in free() argument 84 return __hip_free(__ptr); in free() 91 __attribute__((weak)) inline __device__ void *free(void *__ptr) {
|
| H A D | vecintrin.h | 316 __vec[7] = *__ptr; in vec_insert_and_zero() 323 __vec[7] = *__ptr; in vec_insert_and_zero() 330 __vec[3] = *__ptr; in vec_insert_and_zero() 337 __vec[3] = *__ptr; in vec_insert_and_zero() 344 __vec[1] = *__ptr; in vec_insert_and_zero() 351 __vec[1] = *__ptr; in vec_insert_and_zero() 358 __vec[0] = *__ptr; in vec_insert_and_zero() 365 __vec[0] = *__ptr; in vec_insert_and_zero() 373 __vec[1] = *__ptr; in vec_insert_and_zero() 381 __vec[0] = *__ptr; in vec_insert_and_zero() [all …]
|
| H A D | arm_acle.h | 725 #define __arm_mte_create_random_tag(__ptr, __mask) __builtin_arm_irg(__ptr, __mask) argument 726 #define __arm_mte_increment_tag(__ptr, __tag_offset) __builtin_arm_addg(__ptr, __tag_offset) argument 727 #define __arm_mte_exclude_tag(__ptr, __excluded) __builtin_arm_gmi(__ptr, __excluded) argument 728 #define __arm_mte_get_tag(__ptr) __builtin_arm_ldg(__ptr) argument 729 #define __arm_mte_set_tag(__ptr) __builtin_arm_stg(__ptr) argument
|
| H A D | __clang_cuda_runtime_wrapper.h | 376 __device__ static inline void free(void *__ptr) { ::free(__ptr); } in free() argument
|
| H A D | altivec.h | 17563 return *(unaligned_vec_uchar*)(__ptr + __offset); in vec_xl() 17703 return vec_xl(__offset, __ptr); in vec_xl_be() 17708 return vec_xl(__offset, __ptr); in vec_xl_be() 17913 *(__ptr + __offset) = (signed char)__vec[0]; in vec_xst_trunc() 17919 *(__ptr + __offset) = (unsigned char)__vec[0]; in vec_xst_trunc() 17925 *(__ptr + __offset) = (signed short)__vec[0]; in vec_xst_trunc() 17931 *(__ptr + __offset) = (unsigned short)__vec[0]; in vec_xst_trunc() 17937 *(__ptr + __offset) = (signed int)__vec[0]; in vec_xst_trunc() 17943 *(__ptr + __offset) = (unsigned int)__vec[0]; in vec_xst_trunc() 18043 vec_xst(__vec, __offset, __ptr); in vec_xst_be() [all …]
|
| /freebsd-13.1/sys/contrib/octeon-sdk/cvmx-malloc/ |
| H A D | malloc.h | 173 extern size_t malloc_usable_size __MALLOC_P ((__malloc_ptr_t __ptr)); 183 extern int malloc_set_state __MALLOC_P ((__malloc_ptr_t __ptr)); 190 extern void (*cvmx__free_hook) __MALLOC_PMT ((__malloc_ptr_t __ptr, 194 extern __malloc_ptr_t (*cvmx__realloc_hook) __MALLOC_PMT ((__malloc_ptr_t __ptr,
|
| H A D | arena.c | 95 static void (*save_free_hook) __MALLOC_P ((__malloc_ptr_t __ptr,
|
| /freebsd-13.1/contrib/llvm-project/libcxx/include/ |
| H A D | new | 269 return __libcpp_operator_delete(__ptr, __args...); 271 return __libcpp_operator_delete(__ptr, __size, __args...); 279 return __do_deallocate_handle_size(__ptr, __size); 283 return __do_deallocate_handle_size(__ptr, __size, __align_val); 285 return __do_deallocate_handle_size(__ptr, __size); 293 return __libcpp_operator_delete(__ptr); 297 return __libcpp_operator_delete(__ptr, __align_val); 299 return __libcpp_operator_delete(__ptr); 324 void __libcpp_aligned_free(void* __ptr) { 326 ::_aligned_free(__ptr); [all …]
|
| H A D | any | 304 constexpr _Storage() : __ptr(nullptr) {} 305 void * __ptr; 462 __dest.__s.__ptr = __hold.release(); 474 _Tp * __p = static_cast<_Tp *>(__this.__s.__ptr); 482 _LargeHandler::__create(__dest, *static_cast<_Tp const *>(__this.__s.__ptr)); 487 __dest.__s.__ptr = __this.__s.__ptr; 497 return static_cast<void*>(__this.__s.__ptr);
|
| H A D | __node_handle | 81 __basic_node_handle(__node_pointer_type __ptr, 83 : __ptr_(__ptr), __alloc_(__alloc)
|
| H A D | __hash_table | 72 __next_pointer __ptr() _NOEXCEPT { 1478 __p1_.first().__ptr(); 1502 __p1_.first().__ptr(); 1621 __p1_.first().__ptr(); 1890 __pn =__p1_.first().__ptr(); 1892 __pn->__next_ = __nd->__ptr(); 1988 __pn =__p1_.first().__ptr(); 1995 = __cp->__ptr(); 2023 return iterator(__cp->__ptr()); 2574 if (__pn == __p1_.first().__ptr() [all …]
|
| H A D | __tree | 2248 iterator __r(__ptr); 2250 if (__begin_node() == __ptr) 2269 __node_pointer __ptr = __nh.__ptr_; 2279 static_cast<__node_base_pointer>(__ptr)); 2294 __node_pointer __ptr = __nh.__ptr_; 2304 __r = __ptr; 2365 __node_pointer __ptr = __nh.__ptr_; 2368 __parent, _NodeTypes::__get_key(__ptr->__value_)); 2371 return iterator(__ptr); 2384 __node_pointer __ptr = __nh.__ptr_; [all …]
|
| H A D | span | 227 …_LIBCPP_INLINE_VISIBILITY constexpr explicit span(pointer __ptr, size_type __count) : __data{__ptr} 405 …_LIBCPP_INLINE_VISIBILITY constexpr span(pointer __ptr, size_type __count) : __data{__ptr}, __size…
|
| H A D | forward_list | 1381 for (__begin_node_pointer __ptr = __p.__get_begin(); __n > 0; --__n, 1382 __ptr = __ptr->__next_as_begin()) 1387 __ptr->__next_ = __h.release(); 1413 for (__begin_node_pointer __ptr = __p.__get_begin(); __n > 0; --__n, 1414 __ptr = __ptr->__next_as_begin()) 1419 __ptr->__next_ = __h.release();
|
| H A D | typeinfo | 220 static size_t __hash(__type_name_t __ptr) _NOEXCEPT { 222 while (unsigned char __c = static_cast<unsigned char>(*__ptr++))
|
| H A D | exception | 220 _LIBCPP_FUNC_VIS exception_ptr __copy_exception_ptr(void *__except, const void* __ptr);
|
| /freebsd-13.1/contrib/llvm-project/libcxx/src/support/runtime/ |
| H A D | exception_pointer_msvc.ipp | 59 exception_ptr __copy_exception_ptr(void* __except, const void* __ptr) { 61 if (__ptr) 62 __ExceptionPtrCopyException(&__ret, __except, __ptr);
|
| /freebsd-13.1/contrib/llvm-project/clang/lib/Headers/cuda_wrappers/ |
| H A D | new | 94 __device__ inline void *operator new(__SIZE_TYPE__, void *__ptr) CUDA_NOEXCEPT { 95 return __ptr; 97 __device__ inline void *operator new[](__SIZE_TYPE__, void *__ptr) CUDA_NOEXCEPT { 98 return __ptr;
|
| /freebsd-13.1/contrib/llvm-project/libcxx/include/__memory/ |
| H A D | unique_ptr.h | 52 _LIBCPP_INLINE_VISIBILITY void operator()(_Tp* __ptr) const _NOEXCEPT { in operator() 57 delete __ptr; in operator() local 83 operator()(_Up* __ptr) const _NOEXCEPT { 88 delete[] __ptr; 762 size_t operator()(const unique_ptr<_Tp, _Dp>& __ptr) const 765 return hash<pointer>()(__ptr.get());
|
| H A D | shared_ptr.h | 661 _OrigPtr* __ptr) _NOEXCEPT 667 const_cast<_RawYp*>(static_cast<const _Yp*>(__ptr))); 1721 size_t operator()(const shared_ptr<_Tp>& __ptr) const _NOEXCEPT 1723 return hash<typename shared_ptr<_Tp>::element_type*>()(__ptr.get());
|